@@ -12,14 +12,15 @@
 #' @param ... other parameters that may be passed to the 'shortening' function that shortens column names
 #' @importFrom XML readHTMLTable
 #' @importFrom utils unzip read.csv
+#' @importFrom data.table fread
 #' @export
 #'
 #' @examples \donttest{
-#'   monthly <- meteo_imgw_monthly(rank = "climate", year = 1969)
+#'   monthly = meteo_imgw_monthly(rank = "climate", year = 1969)
 #'   head(monthly)
 #'
 #'   # a descriptive (long) column names:
-#'   monthly2 <- meteo_imgw_monthly(rank = "synop", year = 2018, 
+#'   monthly2 = meteo_imgw_monthly(rank = "synop", year = 2018, 
 #'          col_names = "full")
 #'   head(monthly2)
 #'   
@@ -29,13 +30,13 @@
 #'           coords = TRUE, station = c("POZNAŃ","POZNAŃ-ŁAWICA")) 
 #' }
 #'
-meteo_imgw_monthly <- function(rank = "synop", year, status = FALSE, coords = FALSE, station = NULL, col_names = "short", ...){
+meteo_imgw_monthly = function(rank = "synop", year, status = FALSE, coords = FALSE, station = NULL, col_names = "short", ...){
 
-  check_locale()
+  translit = check_locale()
   
   #options(RCurlOptions = list(ssl.verifypeer = FALSE)) # required on windows for RCurl
   
-  base_url <- "https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/"
+  base_url = "https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/"
   
   # if (httr::http_error(base_url)) {
   #   b = stop(call. = FALSE, 
@@ -46,104 +47,113 @@ meteo_imgw_monthly <- function(rank = "synop", year, status = FALSE, coords = FA
   # }
   # 
   # 
-  interval_pl <- "miesieczne" # to mozemy ustawic na sztywno do odwolania w url
-  meta <- meteo_metadata_imgw(interval = "monthly", rank = rank)
+  interval_pl = "miesieczne" 
+  meta = meteo_metadata_imgw(interval = "monthly", rank = rank)
   
-  rank_pl <- switch(rank, synop = "synop", climate = "klimat", precip = "opad")
+  rank_pl = switch(rank, synop = "synop", climate = "klimat", precip = "opad")
   
-  # checking net connection:
+  # checking internet connection:
   temp = tempfile()
   test_url(link = paste0(base_url, "dane_meteorologiczne/", interval_pl, "/", rank_pl, "/"),
            output = temp)
   a = readLines(temp, warn = FALSE)
   unlink(temp)
   
-  # a <- getURL(paste0(base_url, "dane_meteorologiczne/", interval, "/", rank_pl, "/"),
-  #             ftp.use.epsv = FALSE,
-  #             dirlistonly = TRUE)
-  ind <- grep(readHTMLTable(a)[[1]]$Name, pattern = "/")
-  catalogs <- as.character(readHTMLTable(a)[[1]]$Name[ind])
+  ind = grep(readHTMLTable(a)[[1]]$Name, pattern = "/")
+  catalogs = as.character(readHTMLTable(a)[[1]]$Name[ind])
   
-  # fragment dla lat (ktore catalogs wymagaja pobrania:
-  years_in_catalogs <- strsplit(gsub(x = catalogs, pattern = "/", replacement = ""), split = "_")
-  years_in_catalogs <- lapply(years_in_catalogs, function(x) x[1]:x[length(x)])
-  ind <- lapply(years_in_catalogs, function(x) sum(x %in% year) > 0)
-  catalogs <- catalogs[unlist(ind)] # to sa nasze prawdziwe catalogs do przemielenia
+  # check for catalogs / years that require downloading:
+  years_in_catalogs = strsplit(gsub(x = catalogs, pattern = "/", replacement = ""), split = "_")
+  years_in_catalogs = lapply(years_in_catalogs, function(x) x[1]:x[length(x)])
+  ind = lapply(years_in_catalogs, function(x) sum(x %in% year) > 0)
+  catalogs = catalogs[unlist(ind)]
   
-  all_data <- vector("list", length = length(catalogs))
+  all_data = vector("list", length = length(catalogs))
   
   for (i in seq_along(catalogs)){
     # print(i)
-    catalog <- gsub(catalogs[i], pattern = "/", replacement = "")
+    catalog = gsub(catalogs[i], pattern = "/", replacement = "")
     
     if(rank == "synop") {
-      address <- paste0(base_url, "dane_meteorologiczne/miesieczne/synop",
+      address = paste0(base_url, "dane_meteorologiczne/miesieczne/synop",
                         "/", catalog, "/", catalog, "_m_s.zip")
     }
     if(rank == "climate") {
-      address <- paste0(base_url, "dane_meteorologiczne/miesieczne/klimat",
+      address = paste0(base_url, "dane_meteorologiczne/miesieczne/klimat",
                         "/", catalog, "/", catalog, "_m_k.zip")
     }
     if(rank == "precip") {
-      address <- paste0(base_url, "dane_meteorologiczne/miesieczne/opad",
+      address = paste0(base_url, "dane_meteorologiczne/miesieczne/opad",
                         "/", catalog, "/", catalog, "_m_o.zip")
     }
     
-    temp <- tempfile()
-    temp2 <- tempfile()
+    temp = tempfile()
+    temp2 = tempfile()
     test_url(address, temp)
     #download.file(address, temp)
     unzip(zipfile = temp, exdir = temp2)
-    file1 <- paste(temp2, dir(temp2), sep = "/")[1]
-    data1 <- read.csv(file1, header = FALSE, stringsAsFactors = FALSE, fileEncoding = "CP1250")
-    colnames(data1) <- meta[[1]]$parameters
+    file1 = paste(temp2, dir(temp2), sep = "/")[1]
     
-    if( rank != "precip"){ # w opadowkach jest tylko jeden plik
-      file2 <- paste(temp2, dir(temp2), sep = "/")[2]
-      data2 <- read.csv(file2, header = FALSE, stringsAsFactors = FALSE, fileEncoding = "CP1250")
-      colnames(data2) <- meta[[2]]$parameters
+    if(translit){
+      data1 = as.data.frame(data.table::fread(cmd = paste("iconv -f CP1250 -t ASCII//TRANSLIT", file1)))
+    } else {
+      data1 = read.csv(file1, header = FALSE, stringsAsFactors = FALSE, fileEncoding = "CP1250")
     }
     
-    # usuwa statusy
-    if(status == FALSE){
-      data1[grep("^Status", colnames(data1))] <- NULL
+    colnames(data1) = meta[[1]]$parameters
+    
+    if( rank != "precip"){ # w opadowkach jest tylko jeden plik
+      file2 = paste(temp2, dir(temp2), sep = "/")[2]
       
-      if(rank != "precip"){ # w plikach opadowych tylko jeden plik
-        data2[grep("^Status", colnames(data2))] <- NULL
+      if(translit){
+        data2 = as.data.frame(data.table::fread(cmd = paste("iconv -f CP1250 -t ASCII//TRANSLIT", file2)))
+      } else {
+        data2 = read.csv(file2, header = FALSE, stringsAsFactors = FALSE, fileEncoding = "CP1250")
+      }
+      
+      colnames(data2) = meta[[2]]$parameters
+    }
+    
+    # removing status if set
+    if(status == FALSE){
+      data1[grep("^Status", colnames(data1))] = NULL
+      
+      if(rank != "precip"){ # in precipitation station only 1 file
+        data2[grep("^Status", colnames(data2))] = NULL
       }
     }
     
     unlink(c(temp, temp2))
     
     if(rank != "precip"){
-      all_data[[i]] <- merge(data1, data2,
+      all_data[[i]] = merge(data1, data2,
                              by = c("Kod stacji", "Nazwa stacji", "Rok", "Miesiac"),
                              all.x = TRUE)
     } else {
-      all_data[[i]] <- data1
+      all_data[[i]] = data1
     }
   }
   
-  all_data <- do.call(rbind, all_data)
-  all_data <- all_data[all_data$Rok %in% year, ]
+  all_data = do.call(rbind, all_data)
+  all_data = all_data[all_data$Rok %in% year, ]
   
   if (coords){
-    all_data <- merge(climate::imgw_meteo_stations, all_data, by.x = "id", by.y = "Kod stacji", all.y = TRUE)
+    all_data = merge(climate::imgw_meteo_stations, all_data, by.x = "id", by.y = "Kod stacji", all.y = TRUE)
   }
   
-  # dodaje rank
-  rank_code <- switch(rank, synop = "SYNOPTYCZNA", climate = "KLIMATYCZNA", precip = "OPADOWA")
-  all_data <- cbind(data.frame(rank_code = rank_code), all_data)
+  # add rank
+  rank_code = switch(rank, synop = "SYNOPTYCZNA", climate = "KLIMATYCZNA", precip = "OPADOWA")
+  all_data = cbind(data.frame(rank_code = rank_code), all_data)
   
   #station selection
   if (!is.null(station)) {
     if (is.character(station)) {
-      all_data <- all_data[substr(all_data$`Nazwa stacji`,1,nchar(station))==station, ]
+      all_data = all_data[substr(all_data$`Nazwa stacji`,1,nchar(station))==station, ]
       if (nrow(all_data) == 0){
         stop("Selected station(s) is not available in the database.", call. = FALSE)
       }
     } else if (is.numeric(station)){
-      all_data <- all_data[all_data$`Kod stacji` %in% station, ]
+      all_data = all_data[all_data$`Kod stacji` %in% station, ]
       if (nrow(all_data) == 0){
         stop("Selected station(s) is not available in the database.", call. = FALSE)
       }
@@ -153,16 +163,16 @@ meteo_imgw_monthly <- function(rank = "synop", year, status = FALSE, coords = FA
   }
   
   
-  # sortowanie w zaleznosci od nazw kolumn - raz jest "kod stacji", raz "id"
+  # sorting data accordingly to column names - (could be "kod stacji" or "id")
   if(sum(grepl(x = colnames(all_data), pattern = "Kod stacji"))){
-    all_data <- all_data[order(all_data$`Kod stacji`, all_data$Rok, all_data$Miesiac), ]
+    all_data = all_data[order(all_data$`Kod stacji`, all_data$Rok, all_data$Miesiac), ]
   } else {
-    all_data <- all_data[order(all_data$id, all_data$Rok, all_data$Miesiac), ]
+    all_data = all_data[order(all_data$id, all_data$Rok, all_data$Miesiac), ]
   }
   
   
-  # dodanie opcji  dla skracania kolumn i usuwania duplikatow:
-  all_data <- meteo_shortening_imgw(all_data, col_names = col_names, ...)
+  # adding option to shorten columns and removing duplicates:
+  all_data = meteo_shortening_imgw(all_data, col_names = col_names, ...)
   
-  return(all_data) # przyciecie tylko do wybranych lat gdyby sie pobralo za duzo
+  return(all_data) # clipping to selected years only
 }
