@@ -65,16 +65,16 @@
 #'   # head(poznan)
 #' }
 #'
-meteo_ogimet <- function(interval, date, coords = FALSE, station, precip_split = TRUE){
+meteo_ogimet = function(interval, date, coords = FALSE, station, precip_split = TRUE){
   if (interval == "daily"){
     # daily
     if (!precip_split){
       warning("The `precip_split` argument is only valid for hourly time step", call. = FALSE)
     }
-    all_data <- ogimet_daily(date = date,  coords = coords, station = station)
+    all_data = ogimet_daily(date = date,  coords = coords, station = station)
   } else if (interval == "hourly"){
     #hourly
-    all_data <- ogimet_hourly(date = date,  coords = coords, station = station,
+    all_data = ogimet_hourly(date = date,  coords = coords, station = station,
                               precip_split = precip_split)
   } else{
     stop("Wrong `interval` value. It should be either 'hourly' or 'daily'")
