@@ -8,13 +8,13 @@
 #'
 #' @examples
 #' \donttest{
-#'  df <- climate:::ogimet_hourly(station = 12330)
+#'  df = climate:::ogimet_hourly(station = 12330)
 #'  climate:::precip_split(df$Precmm, pattern = "/12") # to get 12h precipitation amounts
 #' }
 #'
-precip_split <- function(precip,  pattern = "/12"){
-  b <- strsplit(precip, "h", fixed = TRUE)
-  b <- lapply(b, function(x) x[grepl(x, pattern = pattern, fixed = TRUE)])
-  b <- unlist(lapply(b, function(x) ifelse(length(x) > 0, gsub(x = x, pattern = pattern, replacement = ""), NA)))
+precip_split = function(precip,  pattern = "/12"){
+  b = strsplit(precip, "h", fixed = TRUE)
+  b = lapply(b, function(x) x[grepl(x, pattern = pattern, fixed = TRUE)])
+  b = unlist(lapply(b, function(x) ifelse(length(x) > 0, gsub(x = x, pattern = pattern, replacement = ""), NA)))
   suppressWarnings(as.numeric(as.character(b)))
 }
